@@ -26,9 +26,12 @@
 #include <QComboBox>
 #include <QGridLayout>
 #include <QLabel>
+#include <QStringList>
 #include <QWidget>
 #include "Common.h"
+#include "FilterTextTranslator.h"
 #include "HtmlTranslator.h"
+#include "Logger.h"
 
 ChoiceParameter::ChoiceParameter(QObject * parent) : AbstractParameter(parent, true), _default(0), _value(0), _label(nullptr), _comboBox(nullptr), _connected(false) {}
 
@@ -38,12 +41,11 @@ ChoiceParameter::~ChoiceParameter()
   delete _label;
 }
 
-void ChoiceParameter::addTo(QWidget * widget, int row)
+bool ChoiceParameter::addTo(QWidget * widget, int row)
 {
-  auto grid = dynamic_cast<QGridLayout *>(widget->layout());
-  if (!grid) {
-    return;
-  }
+  _grid = dynamic_cast<QGridLayout *>(widget->layout());
+  Q_ASSERT_X(_grid, __PRETTY_FUNCTION__, "No grid layout in widget");
+  _row = row;
   delete _comboBox;
   delete _label;
 
@@ -51,9 +53,10 @@ void ChoiceParameter::addTo(QWidget * widget, int row)
   _comboBox->addItems(_choices);
   _comboBox->setCurrentIndex(_value);
 
-  grid->addWidget(_label = new QLabel(_name, widget), row, 0, 1, 1);
-  grid->addWidget(_comboBox, row, 1, 1, 2);
+  _grid->addWidget(_label = new QLabel(_name, widget), row, 0, 1, 1);
+  _grid->addWidget(_comboBox, row, 1, 1, 2);
   connectComboBox();
+  return true;
 }
 
 QString ChoiceParameter::textValue() const
@@ -82,7 +85,10 @@ void ChoiceParameter::reset()
 bool ChoiceParameter::initFromText(const char * text, int & textLength)
 {
   QStringList list = parseText("choice", text, textLength);
-  _name = HtmlTranslator::html2txt(list[0]);
+  if (list.isEmpty()) {
+    return false;
+  }
+  _name = HtmlTranslator::html2txt(FilterTextTranslator::translate(list[0]));
   _choices = list[1].split(QChar(','));
   bool ok;
   if (_choices.isEmpty()) {
@@ -97,7 +103,7 @@ bool ChoiceParameter::initFromText(const char * text, int & textLength)
   QList<QString>::iterator it = _choices.begin();
   while (it != _choices.end()) {
     *it = it->trimmed().remove(QRegExp("^\"")).remove(QRegExp("\"$"));
-    *it = HtmlTranslator::html2txt(*it);
+    *it = HtmlTranslator::html2txt(FilterTextTranslator::translate(*it));
     ++it;
   }
   _value = _default;
