@@ -36,6 +36,7 @@
 #include <cstdio>
 #include "Common.h"
 #include "DialogSettings.h"
+#include "FilterTextTranslator.h"
 #include "HtmlTranslator.h"
 
 ColorParameter::ColorParameter(QObject * parent) : AbstractParameter(parent, true), _default(0, 0, 0, 0), _value(_default), _alphaChannel(false), _label(nullptr), _button(nullptr), _dialog(nullptr) {}
@@ -47,12 +48,11 @@ ColorParameter::~ColorParameter()
   delete _dialog;
 }
 
-void ColorParameter::addTo(QWidget * widget, int row)
+bool ColorParameter::addTo(QWidget * widget, int row)
 {
-  auto grid = dynamic_cast<QGridLayout *>(widget->layout());
-  if (!grid) {
-    return;
-  }
+  _grid = dynamic_cast<QGridLayout *>(widget->layout());
+  Q_ASSERT_X(_grid, __PRETTY_FUNCTION__, "No grid layout in widget");
+  _row = row;
   delete _button;
   delete _label;
 
@@ -68,9 +68,10 @@ void ColorParameter::addTo(QWidget * widget, int row)
 
   updateButtonColor();
 
-  grid->addWidget(_label = new QLabel(_name, widget), row, 0, 1, 1);
-  grid->addWidget(_button, row, 1, 1, 1);
+  _grid->addWidget(_label = new QLabel(_name, widget), row, 0, 1, 1);
+  _grid->addWidget(_button, row, 1, 1, 1);
   connect(_button, SIGNAL(clicked()), this, SLOT(onButtonPressed()));
+  return true;
 }
 
 QString ColorParameter::textValue() const
@@ -108,7 +109,27 @@ void ColorParameter::reset()
 bool ColorParameter::initFromText(const char * text, int & textLength)
 {
   QList<QString> list = parseText("color", text, textLength);
-  _name = HtmlTranslator::html2txt(list[0]);
+  if (list.isEmpty()) {
+    return false;
+  }
+  _name = HtmlTranslator::html2txt(FilterTextTranslator::translate(list[0]));
+
+  // color(#e9cc00) and color(#e9cc00ff)
+  const QString trimmed = list[1].trimmed();
+  QRegExp colorRE("#[0-9a-fA-F]{6,8}");
+  if (colorRE.exactMatch(trimmed)) {
+    _default = QColor(trimmed.left(7));
+    if (trimmed.length() == 9) {
+      _alphaChannel = true;
+      _default.setAlpha(trimmed.right(2).toInt(nullptr, 16));
+    } else {
+      _alphaChannel = false;
+    }
+    _value = _default;
+    return true;
+  }
+
+  // color(120,100,10) and color(120,100,10,128)
   QList<QString> channels = list[1].split(",");
   const int n = channels.size();
   bool okR = true, okG = true, okB = true, okA = true;
