@@ -22,8 +22,8 @@
  *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef _GMIC_QT_POINTPARAMETER_H_
-#define _GMIC_QT_POINTPARAMETER_H_
+#ifndef GMIC_QT_POINTPARAMETER_H
+#define GMIC_QT_POINTPARAMETER_H
 
 #include <QColor>
 #include <QColorDialog>
@@ -42,9 +42,8 @@ class PointParameter : public AbstractParameter {
   Q_OBJECT
 public:
   PointParameter(QObject * parent = nullptr);
-  ~PointParameter();
-  bool isVisible() const override;
-  void addTo(QWidget *, int row) override;
+  ~PointParameter() override;
+  bool addTo(QWidget *, int row) override;
   void addToKeypointList(KeypointList &) const override;
   void extractPositionFromKeypointList(KeypointList &) override;
   QString textValue() const override;
@@ -55,6 +54,8 @@ public:
 
   static void resetDefaultColorIndex();
 
+  void setVisibilityState(AbstractParameter::VisibilityState state) override;
+
 public slots:
   void enableNotifications(bool);
 
@@ -67,6 +68,7 @@ private:
   void connectSpinboxes();
   void disconnectSpinboxes();
   void pickColorFromDefaultColormap();
+  void updateView();
   QString _name;
   QPointF _defaultPosition;
   bool _defaultRemovedStatus;
@@ -74,8 +76,7 @@ private:
   QColor _color;
   bool _removable;
   bool _burst;
-  int _radius;
-  bool _visible;
+  float _radius;
   bool _keepOpacityWhenSelected;
 
   QLabel * _label;
@@ -93,4 +94,4 @@ private:
   static unsigned long _randomSeed;
 };
 
-#endif // _GMIC_QT_POINTPARAMETER_H_
+#endif // GMIC_QT_POINTPARAMETER_H
