@@ -22,8 +22,8 @@
  *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef _GMIC_QT_FAVESMODEL_H_
-#define _GMIC_QT_FAVESMODEL_H_
+#ifndef GMIC_QT_FAVESMODEL_H
+#define GMIC_QT_FAVESMODEL_H
 #include <QList>
 #include <QMap>
 #include <QString>
@@ -39,16 +39,18 @@ public:
     Fave & setPreviewCommand(const QString & command);
     Fave & setOriginalHash(const QString & hash);
     Fave & setDefaultValues(const QList<QString> & defaultValues);
+    Fave & setDefaultVisibilities(const QList<int> & defaultVisibilityStates);
     Fave & build();
 
-    QString name() const;
-    QString plainText() const;
-    QString originalName() const;
-    QString originalHash() const;
-    QString command() const;
-    QString previewCommand() const;
-    QString hash() const;
-    QList<QString> defaultValues() const;
+    const QString & name() const;
+    const QString & plainText() const;
+    const QString & originalName() const;
+    const QString & originalHash() const;
+    const QString & command() const;
+    const QString & previewCommand() const;
+    const QString & hash() const;
+    const QList<QString> & defaultValues() const;
+    const QList<int> & defaultVisibilityStates() const;
     QString toString() const;
     bool matchKeywords(const QList<QString> & keywords) const;
 
@@ -61,6 +63,7 @@ public:
     QString _hash;
     QString _originalHash;
     QList<QString> _defaultValues;
+    QList<int> _defaultVisibilityStates;
   };
 
   class const_iterator {
@@ -89,8 +92,8 @@ public:
   bool contains(const QString & hash) const;
   void flush() const;
   size_t faveCount() const;
-  const_iterator findFaveFromHash(const QString &);
-  const Fave & getFaveFromHash(const QString & hash);
+  const_iterator findFaveFromHash(const QString &) const;
+  const Fave & getFaveFromHash(const QString & hash) const;
   QString uniqueName(const QString & name, const QString & faveHashToIgnore);
   static const size_t NoIndex;
 
@@ -120,4 +123,4 @@ FavesModel::const_iterator FavesModel::end() const
 {
   return FavesModel::const_iterator(_faves.end());
 }
-#endif // _GMIC_QT_FAVESMODEL_H_
+#endif // GMIC_QT_FAVESMODEL_H
