@@ -22,8 +22,8 @@
  *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef _GMIC_QT_FAVESMODELWRITER_H_
-#define _GMIC_QT_FAVESMODELWRITER_H_
+#ifndef GMIC_QT_FAVESMODELWRITER_H
+#define GMIC_QT_FAVESMODELWRITER_H
 #include <QJsonObject>
 #include "FilterSelector/FavesModel.h"
 
@@ -39,4 +39,4 @@ private:
   static QJsonObject faveToJsonObject(const FavesModel::Fave & fave);
   const FavesModel & _model;
 };
-#endif // _GMIC_QT_FAVESMODELWRITER_H_
+#endif // GMIC_QT_FAVESMODELWRITER_H
