@@ -22,8 +22,8 @@
  *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef _GMIC_QT_FILTERSVISIBILITYMAP_H_
-#define _GMIC_QT_FILTERSVISIBILITYMAP_H_
+#ifndef GMIC_QT_FILTERSVISIBILITYMAP_H
+#define GMIC_QT_FILTERSVISIBILITYMAP_H
 
 #include <QSet>
 
@@ -40,4 +40,4 @@ private:
   FiltersVisibilityMap() = delete;
 };
 
-#endif // _GMIC_QT_FILTERSVISIBILITYMAP_H_
+#endif // GMIC_QT_FILTERSVISIBILITYMAP_H
