@@ -54,6 +54,7 @@ GmicProcessor::GmicProcessor(QObject * parent) : QObject(parent)
   _previewRandomSeed = cimg_library::cimg::_rand();
   _lastAppliedCommandInOutState = GmicQt::InputOutputState::Unspecified;
   _filterExecutionTime.start();
+  _completeFullImageProcessingCount = 0;
 }
 
 void GmicProcessor::init()
@@ -93,7 +94,7 @@ void GmicProcessor::execute()
     FilterSyncRunner runner(this, _filterContext.filterName, _filterContext.filterCommand, _filterContext.filterArguments, env, _filterContext.outputMessageMode);
     runner.swapImages(*_gmicImages);
     runner.setImageNames(imageNames);
-    runner.setLogSuffix("./preview/");
+    runner.setLogSuffix("preview");
     cimg_library::cimg::srand();
     _previewRandomSeed = cimg_library::cimg::_rand();
     _filterExecutionTime.restart();
@@ -104,7 +105,7 @@ void GmicProcessor::execute()
     _filterThread = new FilterThread(this, _filterContext.filterName, _filterContext.filterCommand, _filterContext.filterArguments, env, _filterContext.outputMessageMode);
     _filterThread->swapImages(*_gmicImages);
     _filterThread->setImageNames(imageNames);
-    _filterThread->setLogSuffix("./preview/");
+    _filterThread->setLogSuffix("preview");
     connect(_filterThread, SIGNAL(finished()), this, SLOT(onPreviewThreadFinished()), Qt::QueuedConnection);
     cimg_library::cimg::srand();
     _previewRandomSeed = cimg_library::cimg::_rand();
@@ -119,7 +120,7 @@ void GmicProcessor::execute()
     _filterThread = new FilterThread(this, _filterContext.filterName, _filterContext.filterCommand, _filterContext.filterArguments, env, _filterContext.outputMessageMode);
     _filterThread->swapImages(*_gmicImages);
     _filterThread->setImageNames(imageNames);
-    _filterThread->setLogSuffix("./apply/");
+    _filterThread->setLogSuffix("apply");
     connect(_filterThread, SIGNAL(finished()), this, SLOT(onApplyThreadFinished()), Qt::QueuedConnection);
     cimg_library::cimg::srand(_previewRandomSeed);
     _filterThread->start();
@@ -197,6 +198,11 @@ void GmicProcessor::setGmicStatusQuotedParameters(const QString & v)
   _gmicStatusQuotedParameters = v;
 }
 
+int GmicProcessor::completedFullImageProcessingCount() const
+{
+  return _completeFullImageProcessingCount;
+}
+
 void GmicProcessor::cancel()
 {
   abortCurrentFilterThread();
@@ -248,6 +254,7 @@ void GmicProcessor::onPreviewThreadFinished()
   }
   if (_filterThread->failed()) {
     _gmicStatus.clear();
+    _parametersVisibilityStates.clear();
     _gmicImages->assign();
     QString message = _filterThread->errorMessage();
     _filterThread->deleteLater();
@@ -257,6 +264,7 @@ void GmicProcessor::onPreviewThreadFinished()
     return;
   }
   _gmicStatus = _filterThread->gmicStatus();
+  _parametersVisibilityStates = _filterThread->parametersVisibilityStates();
   _gmicImages->assign();
   _filterThread->swapImages(*_gmicImages);
   for (unsigned int i = 0; i < _gmicImages->size(); ++i) {
@@ -278,6 +286,7 @@ void GmicProcessor::onApplyThreadFinished()
     return;
   }
   _gmicStatus = _filterThread->gmicStatus();
+  _parametersVisibilityStates = _filterThread->parametersVisibilityStates();
   hideWaitingCursor();
 
   if (_filterThread->failed()) {
@@ -297,14 +306,15 @@ void GmicProcessor::onApplyThreadFinished()
       QString label = QString("[G'MIC] %1: %2").arg(_filterThread->name()).arg(_filterThread->fullCommand());
       gmic_qt_output_images(*_gmicImages, _filterThread->imageNames(), _filterContext.inputOutputState.outputMode, label.toLocal8Bit().constData());
     } else {
-      gmic_qt_output_images(*_gmicImages, _filterThread->imageNames(), _filterContext.inputOutputState.outputMode, 0);
+      gmic_qt_output_images(*_gmicImages, _filterThread->imageNames(), _filterContext.inputOutputState.outputMode, nullptr);
     }
+    _completeFullImageProcessingCount += 1;
     LayersExtentProxy::clear();
     CroppedActiveLayerProxy::clear();
     CroppedImageListProxy::clear();
     _filterThread->deleteLater();
     _filterThread = nullptr;
-    _lastAppliedCommandGmicStatus = _gmicStatus;
+    _lastAppliedCommandGmicStatus = _gmicStatus; // TODO : save visibility states?
     emit fullImageProcessingDone();
   }
 }
@@ -382,6 +392,7 @@ void GmicProcessor::manageSynchonousRunner(FilterSyncRunner & runner)
     return;
   }
   _gmicStatus = runner.gmicStatus();
+  _parametersVisibilityStates = runner.parametersVisibilityStates();
   _gmicImages->assign();
   runner.swapImages(*_gmicImages);
   for (unsigned int i = 0; i < _gmicImages->size(); ++i) {
@@ -391,3 +402,8 @@ void GmicProcessor::manageSynchonousRunner(FilterSyncRunner & runner)
   hideWaitingCursor();
   emit previewImageAvailable();
 }
+
+const QList<int> & GmicProcessor::parametersVisibilityStates() const
+{
+  return _parametersVisibilityStates;
+}
