@@ -42,6 +42,8 @@
  * of the GTK version of the gmic plug-in for GIMP by David Tschumperl\'e.
  */
 
+#define GIMP_VERSION_LTE(MAJOR, MINOR) (GIMP_MAJOR_VERSION < MAJOR) || ((GIMP_MAJOR_VERSION == MAJOR) && (GIMP_MINOR_VERSION <= MINOR))
+
 #define _gimp_image_get_item_position gimp_image_get_item_position
 
 #if (GIMP_MAJOR_VERSION == 2) && (GIMP_MINOR_VERSION <= 7) && (GIMP_MICRO_VERSION <= 14)
@@ -54,6 +56,12 @@ namespace GmicQt
 {
 const QString HostApplicationName = QString("GIMP %1.%2").arg(GIMP_MAJOR_VERSION).arg(GIMP_MINOR_VERSION);
 const char * HostApplicationShortname = GMIC_QT_XSTRINGIFY(GMIC_HOST);
+#if GIMP_VERSION_LTE(2, 8)
+const bool DarkThemeIsDefault = false;
+#else
+const bool DarkThemeIsDefault = true;
+#endif
+
 } // namespace GmicQt
 
 namespace
@@ -273,7 +281,7 @@ void gmic_qt_show_message(const char * message)
 
 void gmic_qt_apply_color_profile(cimg_library::CImg<float> & image)
 {
-#if (GIMP_MAJOR_VERSION < 2) || ((GIMP_MAJOR_VERSION == 2) && (GIMP_MINOR_VERSION <= 8))
+#if GIMP_VERSION_LTE(2, 8)
   unused(image);
 // SWAP RED<->GREEN CHANNELS : FOR TESTING PURPOSE ONLY!
 //  cimg_forXY(image,x,y) {
@@ -316,7 +324,7 @@ void gmic_qt_get_layers_extent(int * width, int * height, GmicQt::InputMode mode
   const int * endLayers = begLayers + layersCount;
   int activeLayerID = gimp_image_get_active_layer(gmic_qt_gimp_image_id);
 
-  // Buil list of input layers IDs
+  // Build list of input layers IDs
   std::vector<int> layers;
   switch (mode) {
   case GmicQt::NoInput:
@@ -327,7 +335,6 @@ void gmic_qt_get_layers_extent(int * width, int * height, GmicQt::InputMode mode
     }
     break;
   case GmicQt::All:
-  case GmicQt::AllDesc:
     layers.assign(begLayers, endLayers);
     break;
   case GmicQt::ActiveAndBelow:
@@ -348,11 +355,9 @@ void gmic_qt_get_layers_extent(int * width, int * height, GmicQt::InputMode mode
       layers.push_back(activeLayerID);
     }
     break;
-  case GmicQt::AllVisibles:
-  case GmicQt::AllVisiblesDesc:
-  case GmicQt::AllInvisibles:
-  case GmicQt::AllInvisiblesDesc: {
-    bool visibility = (mode == GmicQt::AllVisibles || mode == GmicQt::AllVisiblesDesc);
+  case GmicQt::AllVisible:
+  case GmicQt::AllInvisible: {
+    bool visibility = (mode == GmicQt::AllVisible);
     for (int i = 0; i < layersCount; ++i) {
       if (_gimp_item_get_visible(begLayers[i]) == visibility) {
         layers.push_back(begLayers[i]);
@@ -413,7 +418,7 @@ void gmic_qt_get_cropped_images(gmic_list<float> & images, gmic_list<char> & ima
     height = 1.0;
   }
 
-  // Buil list of input layers IDs
+  // Build list of input layers IDs
   inputLayers.clear();
   switch (mode) {
   case GmicQt::NoInput:
@@ -424,11 +429,7 @@ void gmic_qt_get_cropped_images(gmic_list<float> & images, gmic_list<char> & ima
     }
     break;
   case GmicQt::All:
-  case GmicQt::AllDesc:
     inputLayers.assign(layers, end_layers);
-    if (mode == GmicQt::AllDesc) {
-      std::reverse(inputLayers.begin(), inputLayers.end());
-    }
     break;
   case GmicQt::ActiveAndBelow:
     if ((active_layer_id >= 0) && !gimp_item_is_group(active_layer_id)) {
@@ -448,19 +449,14 @@ void gmic_qt_get_cropped_images(gmic_list<float> & images, gmic_list<char> & ima
       inputLayers.push_back(active_layer_id);
     }
     break;
-  case GmicQt::AllVisibles:
-  case GmicQt::AllVisiblesDesc:
-  case GmicQt::AllInvisibles:
-  case GmicQt::AllInvisiblesDesc: {
-    bool visibility = (mode == GmicQt::AllVisibles || mode == GmicQt::AllVisiblesDesc);
+  case GmicQt::AllVisible:
+  case GmicQt::AllInvisible: {
+    bool visibility = (mode == GmicQt::AllVisible);
     for (int i = 0; i < layersCount; ++i) {
       if (_gimp_item_get_visible(layers[i]) == visibility) {
         inputLayers.push_back(layers[i]);
       }
     }
-    if (mode == GmicQt::AllVisiblesDesc || mode == GmicQt::AllInvisiblesDesc) {
-      std::reverse(inputLayers.begin(), inputLayers.end());
-    }
   } break;
   default:
     break;
@@ -527,7 +523,7 @@ void gmic_qt_get_cropped_images(gmic_list<float> & images, gmic_list<char> & ima
     QString name = QString("mode(%1),opacity(%2),pos(%3,%4),name(%5)").arg(blendingMode2String(blendMode)).arg(opacity).arg(xPos).arg(yPos).arg(noParenthesisName);
     QByteArray ba = name.toUtf8();
     gmic_image<char>::string(ba.constData()).move_to(imageNames[l]);
-#if (GIMP_MAJOR_VERSION < 2) || ((GIMP_MAJOR_VERSION == 2) && (GIMP_MINOR_VERSION <= 8))
+#if GIMP_VERSION_LTE(2, 8)
     GimpDrawable * drawable = gimp_drawable_get(inputLayers[l]);
     GimpPixelRgn region;
     gimp_pixel_rgn_init(&region, drawable, ix, iy, iw, ih, false, false);
@@ -622,14 +618,10 @@ void gmic_qt_output_images(gmic_list<gmic_pixel_type> & images, const gmic_list<
         gimp_drawable_offsets(inputLayers[p], &layer_posx, &layer_posy);
         cimg_library::CImg<char>::string(gimp_item_get_name(inputLayers[p])).move_to(layer_name);
         get_output_layer_props(imageNames[p], layer_blendmode, layer_opacity, layer_posx, layer_posy, layer_name);
-        if (is_selection) {
-          layer_posx = 0;
-          layer_posy = 0;
-        }
         cimg_library::CImg<gmic_pixel_type> & img = images[p];
         GmicQt::calibrate_image(img, inputLayerDimensions(p, 3), false);
         if (gimp_drawable_mask_intersect(inputLayers[p], &rgn_x, &rgn_y, &rgn_width, &rgn_height)) {
-#if (GIMP_MAJOR_VERSION < 2) || ((GIMP_MAJOR_VERSION == 2) && (GIMP_MINOR_VERSION <= 8))
+#if GIMP_VERSION_LTE(2, 8)
           GimpDrawable * drawable = gimp_drawable_get(inputLayers[p]);
           GimpPixelRgn region;
           gimp_pixel_rgn_init(&region, drawable, rgn_x, rgn_y, rgn_width, rgn_height, true, true);
@@ -652,8 +644,15 @@ void gmic_qt_output_images(gmic_list<gmic_pixel_type> & images, const gmic_list<
 #endif
           gimp_layer_set_mode(inputLayers[p], layer_blendmode);
           gimp_layer_set_opacity(inputLayers[p], layer_opacity);
-          gimp_layer_set_offsets(inputLayers[p], layer_posx, layer_posy);
-
+          if (!is_selection) {
+            gimp_layer_set_offsets(inputLayers[p], layer_posx, layer_posy);
+          } else {
+#if GIMP_VERSION_LTE(2, 8)
+            gimp_layer_translate(inputLayers[p], 0, 0);
+#else
+            gimp_item_transform_translate(inputLayers[p], 0, 0);
+#endif
+          }
           if (verboseLayersLabel) { // Verbose (layer name)
             gimp_item_set_name(inputLayers[p], verboseLayersLabel);
           } else if (layer_name) {
@@ -707,7 +706,7 @@ void gmic_qt_output_images(gmic_list<gmic_pixel_type> & images, const gmic_list<
           }
           gimp_image_insert_layer(gmic_qt_gimp_image_id, layer_id, -1, layer_pos + p);
 
-#if (GIMP_MAJOR_VERSION < 2) || ((GIMP_MAJOR_VERSION == 2) && (GIMP_MINOR_VERSION <= 8))
+#if GIMP_VERSION_LTE(2, 8)
           GimpDrawable * drawable = gimp_drawable_get(layer_id);
           GimpPixelRgn region;
           gimp_pixel_rgn_init(&region, drawable, 0, 0, drawable->width, drawable->height, true, true);
@@ -785,7 +784,7 @@ void gmic_qt_output_images(gmic_list<gmic_pixel_type> & images, const gmic_list<
           }
           gimp_image_insert_layer(gmic_qt_gimp_image_id, layer_id, -1, p);
 
-#if (GIMP_MAJOR_VERSION < 2) || ((GIMP_MAJOR_VERSION == 2) && (GIMP_MINOR_VERSION <= 8))
+#if GIMP_VERSION_LTE(2, 8)
           GimpDrawable * drawable = gimp_drawable_get(layer_id);
           GimpPixelRgn region;
           gimp_pixel_rgn_init(&region, drawable, 0, 0, drawable->width, drawable->height, true, true);
@@ -826,7 +825,7 @@ void gmic_qt_output_images(gmic_list<gmic_pixel_type> & images, const gmic_list<
     const unsigned int max_width = (unsigned int)bottom_right.x;
     const unsigned int max_height = (unsigned int)bottom_right.y;
     if (active_layer_id >= 0) {
-#if (GIMP_MAJOR_VERSION < 2) || ((GIMP_MAJOR_VERSION == 2) && (GIMP_MINOR_VERSION <= 8))
+#if GIMP_VERSION_LTE(2, 8)
       const int nimage_id = gimp_image_new(max_width, max_height, max_spectrum <= 2 ? GIMP_GRAY : GIMP_RGB);
 #else
       const int nimage_id = gimp_image_new_with_precision(max_width, max_height, max_spectrum <= 2 ? GIMP_GRAY : GIMP_RGB, gimp_image_get_precision(gmic_qt_gimp_image_id));
@@ -863,7 +862,7 @@ void gmic_qt_output_images(gmic_list<gmic_pixel_type> & images, const gmic_list<
           }
           gimp_image_insert_layer(nimage_id, layer_id, -1, p);
 
-#if (GIMP_MAJOR_VERSION < 2) || ((GIMP_MAJOR_VERSION == 2) && (GIMP_MINOR_VERSION <= 8))
+#if GIMP_VERSION_LTE(2, 8)
           GimpDrawable * drawable = gimp_drawable_get(layer_id);
           GimpPixelRgn region;
           gimp_pixel_rgn_init(&region, drawable, 0, 0, drawable->width, drawable->height, true, true);
@@ -909,7 +908,6 @@ void gmic_qt_run(const gchar * /* name */, gint /* nparams */, const GimpParam *
   *nreturn_vals = 1;
   return_values[0].type = GIMP_PDB_STATUS;
   int run_mode = (GimpRunMode)param[0].data.d_int32;
-  GimpPDBStatusType status = GIMP_PDB_SUCCESS;
   switch (run_mode) {
   case GIMP_RUN_INTERACTIVE:
     gmic_qt_gimp_image_id = param[1].data.d_drawable;
@@ -924,7 +922,7 @@ void gmic_qt_run(const gchar * /* name */, gint /* nparams */, const GimpParam *
     launchPluginHeadless(param[5].data.d_string, (GmicQt::InputMode)(param[3].data.d_int32 + GmicQt::NoInput), GmicQt::OutputMode(param[4].data.d_int32 + GmicQt::InPlace));
     break;
   }
-  return_values[0].data.d_status = status;
+  return_values[0].data.d_status = pluginDialogWasAccepted() ? GIMP_PDB_SUCCESS : GIMP_PDB_CANCEL;
 }
 
 void gmic_qt_query()
@@ -934,8 +932,7 @@ void gmic_qt_query()
                                       {GIMP_PDB_DRAWABLE, (gchar *)"drawable", (gchar *)"Input drawable (unused)"},
                                       {GIMP_PDB_INT32, (gchar *)"input",
                                        (gchar *)"Input layers mode, when non-interactive"
-                                                " (0=none, 1=active, 2=all, 3=active & below, 4=active & above, 5=all visibles, 6=all invisibles,"
-                                                " 7=all visibles (decr.), 8=all invisibles (decr.), 9=all (decr.))"},
+                                                " (0=none, 1=active, 2=all, 3=active & below, 4=active & above, 5=all visibles, 6=all invisibles)"},
                                       {GIMP_PDB_INT32, (gchar *)"output",
                                        (gchar *)"Output mode, when non-interactive "
                                                 "(0=in place,1=new layers,2=new active layers,3=new image)"},
@@ -957,10 +954,10 @@ void gmic_qt_query()
                          G_N_ELEMENTS(args),        // nparams
                          0,                         // nreturn_vals
                          args,                      // params
-                         0);                        // return_vals
+                         nullptr);                  // return_vals
   gimp_plugin_menu_register(name, "<Image>/Filters");
 }
 
-GimpPlugInInfo PLUG_IN_INFO = {0, 0, gmic_qt_query, gmic_qt_run};
+GimpPlugInInfo PLUG_IN_INFO = {nullptr, nullptr, gmic_qt_query, gmic_qt_run};
 
 MAIN()
