@@ -22,8 +22,8 @@
  *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef _GMIC_QT_IMAGECONVERTER_H_
-#define _GMIC_QT_IMAGECONVERTER_H_
+#ifndef GMIC_QT_IMAGECONVERTER_H
+#define GMIC_QT_IMAGECONVERTER_H
 
 class QImage;
 namespace cimg_library
@@ -40,4 +40,4 @@ private:
   ImageConverter() = delete;
 };
 
-#endif // _GMIC_QT_IMAGECONVERTER_H_
+#endif // GMIC_QT_IMAGECONVERTER_H
