@@ -22,8 +22,8 @@
  *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef _GMIC_QT_TIMELOGGER_H_
-#define _GMIC_QT_TIMELOGGER_H_
+#ifndef GMIC_QT_TIMELOGGER_H
+#define GMIC_QT_TIMELOGGER_H
 
 #include <cstdio>
 #include <memory>
@@ -42,4 +42,4 @@ private:
   static std::unique_ptr<TimeLogger> _instance;
 };
 
-#endif // _GMIC_QT_TIMELOGGER_H_
+#endif // GMIC_QT_TIMELOGGER_H
